@@ -18,7 +18,7 @@ class AWSMarkThis(Db):
 
     def style_get(self, style):
         '''gets question positions for style.  Returns dict {qno: Rect}'''
-        qry = 'SELECT position FROM style WHERE style=%s'
+        qry = 'SELECT positions FROM style WHERE style=%s'
 
         for row in self.namedselect(qry, (style,)):
             return json.loads(row['positions'])
